﻿using System;
using System.Collections.Generic;
using System.Text;
using CSharpCTI;
using CSharpCTI.Entity;
using System.Windows.Forms;

namespace TestDemoForm
{
    /// <summary>
    /// 监听事件
    /// </summary>
    public class CSharpEvent : IEvent
    {
        /// <summary>
        /// 事件启动线程画面
        /// </summary>
        private Form objectForm;
        /// <summary>
        /// 构造函数
        /// </summary>
        /// <param name="iForm"></param>
        public CSharpEvent(Form iForm)
        {
            objectForm = iForm;
        }
        /// <summary>
        /// 事件委托
        /// </summary>
        public CSharpEventDelegate EventDelegate;
        /// <summary>
        /// 新建用户
        /// </summary>
        /// <param name="user">添加的用户</param>
         void IEvent.onAddUser(Users user)
        {
            objectForm.Invoke(EventDelegate,"新添加用户：" + user.user + Environment.NewLine + "绑定设备：" + user.device + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }

        /// <summary>
        /// 删除用户
        /// </summary>
        /// <param name="user">删除的用户</param>
         void IEvent.onRemoveUser(Users user)
        {
            objectForm.Invoke(EventDelegate,"用户" + user.user + "已经被删除！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 重绑用户
        /// </summary>
        /// <param name="user">重新绑定的用户</param>
         void IEvent.onReBindUser(Users user)
        {
            objectForm.Invoke(EventDelegate, "用户" + user.user + "重新绑定到设备（" + user.device + ")上！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 保持
        /// </summary>
        /// <param name="park">保持状态</param>
         void IEvent.onPark(Parks park)
        {
            objectForm.Invoke(EventDelegate,"主叫号码是" + park.callerid  + "的通话被保持！"+ Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 取消保持
        /// </summary>
        /// <param name="park">取消保持状态</param>
         void IEvent.onUnPark(Parks park) 
        {
            objectForm.Invoke(EventDelegate,"主叫号码是" + park.callerid + "的通话被取消保持！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }

        /// <summary>
        /// 设备状态变化
        /// </summary>
        /// <param name="device"></param>
         void IEvent.onDeviceStatus(Devices device)
        {
            objectForm.Invoke(EventDelegate,"设备（" + device.device + ")状态发生改变！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 弹屏事件
        /// </summary>
        /// <param name="device"></param>
         void IEvent.onPopup(Devices device) 
        {
            objectForm.Invoke(EventDelegate,"设备（" + device.device + ")弹出新信息！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 添加队列
        /// </summary>
        /// <param name="queue"></param>
         void IEvent.onQueueAdd(Queues queue)
        {
            objectForm.Invoke(EventDelegate,"队列（" + queue.queue  + ")已添加！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }

        /// <summary>
        /// 移除队列
        /// </summary>
        /// <param name="queue"></param>
         void IEvent.onQueueRemove(Queues queue)
        {
            objectForm.Invoke(EventDelegate,"队列（" + queue.queue  + ")已被移除！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 队列上线
        /// </summary>
        /// <param name="member"></param>
        /// <param name="queueno"></param>
         void IEvent.onQueueOnline(Members member, string queueno)
        {
            objectForm.Invoke(EventDelegate,"队列（"+ queueno + ")坐席（" + member.agentno  + ")上线！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 队列下线
        /// </summary>
        /// <param name="member"></param>
        /// <param name="queueno"></param>
         void IEvent.onQueueOffline(Members member, string queueno)
        {
            objectForm.Invoke(EventDelegate,"队列（"+ queueno + ")坐席（" + member.agentno  + ")下线！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 队列示忙
        /// </summary>
        /// <param name="member"></param>
        /// <param name="queueno"></param>
         void IEvent.onPause(Members member, string queueno)
        {
            objectForm.Invoke(EventDelegate, "队列（" + queueno + ")坐席（" + member.agentno + ")示忙！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 队列示闲
        /// </summary>
        /// <param name="member"></param>
        /// <param name="queueno"></param>
         void IEvent.onUnPause(Members member, string queueno)
        {
            objectForm.Invoke(EventDelegate,"队列（" + queueno + ")坐席（" + member.agentno + ")示闲！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 客户进入队列
        /// </summary>
         /// <param name="wait"></param>
        /// <param name="queueno"></param>
         void IEvent.onInQueue(Waitingcalls wait, string queueno)
        {
            objectForm.Invoke(EventDelegate,"客户（" + wait.callerid + ")进入队列（" + queueno + ")！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 客户离开队列
        /// </summary>
        /// <param name="wait"></param>
        /// <param name="queueno"></param>
         void IEvent.onOutQueue(Waitingcalls wait, string queueno)
        {
            objectForm.Invoke(EventDelegate,"客户（" + wait.callerid + ")离开队列（" + queueno + ")！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 创建会议
        /// </summary>
        /// <param name="conf"></param>
         void IEvent.onCreateConference(Conferences conf)
        {
            objectForm.Invoke(EventDelegate,"会议（" + conf.confno + ")已被创建！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 关闭会议
        /// </summary>
        /// <param name="conf"></param>
         void IEvent.onCloseConference(Conferences conf)
        {
            objectForm.Invoke(EventDelegate,"会议（" + conf.confno + ")已被关闭！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 进入会议
        /// </summary>
        /// <param name="conf"></param>
         void IEvent.onInConference(Conferences conf)
        {
            objectForm.Invoke(EventDelegate,"与会者（" + conf.usernum  + ")进入会议（"+conf.confno+ ")！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 离开会议
        /// </summary>
        /// <param name="conf"></param>
         void IEvent.onOutConference(Conferences conf)
        {
            objectForm.Invoke(EventDelegate,"与会者（" + conf.usernum  + ")离开会议（"+conf.confno+ ")！" + Environment.NewLine + "时间：" + DateTime.Now.ToString());
        }
        /// <summary>
        /// 会议禁言
        /// </summary>
        /// <param name="conf"></param>
         void IEvent.onBanSpeak(Conferences conf)
        { 
        }

        /// <summary>
        /// 解除禁言
        /// </summary>
        /// <param name="conf"></param>
         void IEvent.onUnBanSpeak(Conferences conf)
        { 
        }
    }
    /// <summary>
    /// 事件输出信息委托
    /// </summary>
    /// <param name="message">输出信息</param>
    public delegate void CSharpEventDelegate(string message);
}
